==> cssdk-1.0.02.2-sources.jar: com/css/sdk/cservice/base/Constants.java <==
package com.css.sdk.cservice.base;

public class Constants {
    public static String PLATFORM_ANDROID = "android";

    /**
     * 用于本地语言的常量
     */

    public static String SP_NAME = "a.ly.cservice.cache-v1.0";
    public static String LAST_QA_TYPE = "last_qa_type";//上次提交反馈选择的问题类型
    public static String KEY_SELECTED_PIC_NUM = "selectedPictureNum";//已选择照片的数量
    public static String KEY_SELECTED_PICS = "selectedPictures";
    public static String KEY_ALL_PICS = "allPictures";
    public static String KEY_MAX_NUM = "max_num";//可选择的照片的最大数量
    public static String KEY_POSITION = "position";//当前预览图的位置
    public static String KEY_PREVIEW_TYPE = "preview_type";
    public static int PREVIEW_TYPE_SELECT = 0;//相册查看大图，支持选择
    public static int PREVIEW_TYPE_VIEW = 1;//仅查看大图

    public static final int HISTORY_RESULT_CODE = 0x00000011;
    public static final int PREVIEW_RESULT_CODE = 0x00000012;
    public static final String KEY_IS_CONFIRM = "is_confirm";

    //fqa状态
    public static String QA_STATUS_WAITING = "WAITING";
    public static String QA_STATUS_WAITING_APPEND = "WAITING_APPEND";
    public static String QA_STATUS_PROCESSING = "PROCESSING";
    public static String QA_STATUS_PROCESSED = "PROCESSED";
    public static String QA_STATUS_PROCESSED_READ = "PROCESSED_READ";
    public static String QA_STATUS_CLOSED = "CLOSED";
    public static String QA_STATUS_DELETED = "DELETED";
    public static String QA_STATUS_CLOSED_TIMEOUT = "CLOSE_TIMEOUT";

    public static String KEY_DETAIL_ID = "key_detail_id";//用户反馈历史记录的每一项id

    public static String KEY_FAQ_TAG= "key_faq_tag";//显示更多推荐问题时候的tag
    public static String KEY_IS_UNREAD = "key_is_unread";

    public static String KEY_RECOMMEND_ID = "key_recommend_id";

    public static String RECOMMENDED_QA_SHOW = "recommend_qa_show";
    public static String LAST_REQUEST_RECOMMEND_QA_LIST_TYPE = "last_request_recommend_type";
    public static String KEY_ORDER_ID = "key_order_id";
    public static String KEY_ORDER_CHANGE_TYPE = "key_order_change_type";
    public static int ORDER_CHANGE_TO_READED = 0;//工单状态由新消息变为已读；
    public static int ORDER_CHANGE_TO_CLOSED = 1;//工单状态变为已解决；
    public static int SCREEN_TYPE_PORT = 0;
    public static int SCREEN_TYPE_LAND = 1;
    public static int SCREEN_TYPE_REVERSE_LAND = 3;
    public static String JSON_VIDEONAME = "videoName";
    public static String JSON_PICNAME = "picName";

}

==> cssdk-1.0.04.5-sources.jar: com/css/sdk/cservice/base/Constants.java <==
package com.css.sdk.cservice.base;

public class Constants {
    public static String PLATFORM_ANDROID = "android";

    /**
     * 用于本地语言的常量
     */

    public static String SP_NAME = "a.ly.cservice.cache-v1.0";
    public static String LAST_QA_TYPE = "last_qa_type";//上次提交反馈选择的问题类型
    public static String KEY_SELECTED_PIC_NUM = "selectedPictureNum";//已选择照片的数量
    public static String KEY_SELECTED_PICS = "selectedPictures";
    public static String KEY_ALL_PICS = "allPictures";
    public static String KEY_MAX_NUM = "max_num";//可选择的照片的最大数量
    public static String KEY_POSITION = "position";//当前预览图的位置
    public static String KEY_PREVIEW_TYPE = "preview_type";
    public static int PREVIEW_TYPE_SELECT = 0;//相册查看大图，支持选择
    public static int PREVIEW_TYPE_VIEW = 1;//仅查看大图

    public static final int HISTORY_RESULT_CODE = 0x00000011;
    public static final int PREVIEW_RESULT_CODE = 0x00000012;
    public static final String KEY_IS_CONFIRM = "is_confirm";

    //fqa状态
    public static String QA_STATUS_WAITING = "WAITING";
    public static String QA_STATUS_WAITING_APPEND = "WAITING_APPEND";
    public static String QA_STATUS_PROCESSING = "PROCESSING";
    public static String QA_STATUS_PROCESSED = "PROCESSED";
    public static String QA_STATUS_PROCESSED_READ = "PROCESSED_READ";
    public static String QA_STATUS_CLOSED = "CLOSED";
    public static String QA_STATUS_DELETED = "DELETED";
    public static String QA_STATUS_CLOSED_TIMEOUT = "CLOSE_TIMEOUT";

    public static String KEY_DETAIL_ID = "key_detail_id";//用户反馈历史记录的每一项id

    public static String KEY_FAQ_TAG = "key_faq_tag";//显示更多推荐问题时候的tag
    public static String KEY_IS_UNREAD = "key_is_unread";

    public static String KEY_RECOMMEND_ID = "key_recommend_id";
    public static String KEY_RECOMMEND_NAME = "key_recommend_name";

    // 用户提交的问题id
    public static String KEY_QU_ID = "key_qu_id";
    public static final int REQUESTCODE_SUBMITSUCCESS_FQADETAIL = 6001;
    public static String KEY_DETIAL_EVALUATE_RESULT = "key_detail_evaluate_result";
    public static String RECOMMENDED_QA_SHOW = "recommend_qa_show";
    public static String LAST_REQUEST_RECOMMEND_QA_LIST_TYPE = "last_request_recommend_type";
    public static String KEY_ORDER_ID = "key_order_id";
    public static String KEY_ORDER_CHANGE_TYPE = "key_order_change_type";
    public static int ORDER_CHANGE_TO_READED = 0;//工单状态由新消息变为已读；
    public static int ORDER_CHANGE_TO_CLOSED = 1;//工单状态变为已解决；
    public static int SCREEN_TYPE_PORT = 0;
    public static int SCREEN_TYPE_LAND = 1;
    public static int SCREEN_TYPE_REVERSE_LAND = 3;
    public static String JSON_VIDEONAME = "videoName";
    public static String JSON_PICNAME = "picName";

}
